pub struct SubmitBlockParameters {
pub _work_id: Option<String>,
}Expand description
Optional argument jsonparametersobject for submitblock RPC request
See the notes for the submit_block RPC.
Fields
_work_id: Option<String>The workid for the block template. Currently unused.
If the server provided a workid, it MUST be included with submissions,
Rationale:
If servers allow all mutations, it may be hard to identify which job it is based on. While it may be possible to verify the submission by its content, it is much easier to compare it to the job issued. It is very easy for the miner to keep track of this. Therefore, using a “workid” is a very cheap solution to enable more mutations.